# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ContactArgs', 'Contact']

@pulumi.input_type
class ContactArgs:
    def __init__(__self__, *,
                 address1: pulumi.Input[_builtins.str],
                 city: pulumi.Input[_builtins.str],
                 country: pulumi.Input[_builtins.str],
                 email: pulumi.Input[_builtins.str],
                 first_name: pulumi.Input[_builtins.str],
                 last_name: pulumi.Input[_builtins.str],
                 phone: pulumi.Input[_builtins.str],
                 postal_code: pulumi.Input[_builtins.str],
                 state_province: pulumi.Input[_builtins.str],
                 address2: Optional[pulumi.Input[_builtins.str]] = None,
                 fax: Optional[pulumi.Input[_builtins.str]] = None,
                 job_title: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Contact resource.

        :param pulumi.Input[_builtins.str] address1: The primary address line (street address, building number, etc.).
        :param pulumi.Input[_builtins.str] city: The city where the contact is located.
        :param pulumi.Input[_builtins.str] country: The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        :param pulumi.Input[_builtins.str] email: The contact's email address.
        :param pulumi.Input[_builtins.str] first_name: The first name of the contact person.
        :param pulumi.Input[_builtins.str] last_name: The last name of the contact person.
        :param pulumi.Input[_builtins.str] phone: The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        :param pulumi.Input[_builtins.str] postal_code: The postal code, ZIP code, or equivalent for the contact's location.
        :param pulumi.Input[_builtins.str] state_province: The state, province, or region where the contact is located.
        :param pulumi.Input[_builtins.str] address2: The secondary address line (apartment, suite, floor, etc.).
        :param pulumi.Input[_builtins.str] fax: The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        :param pulumi.Input[_builtins.str] job_title: The job title or position of the contact person within the organization.
        :param pulumi.Input[_builtins.str] label: A descriptive label for the contact to help identify it.
        :param pulumi.Input[_builtins.str] organization_name: The name of the organization or company associated with the contact.
        """
        pulumi.set(__self__, "address1", address1)
        pulumi.set(__self__, "city", city)
        pulumi.set(__self__, "country", country)
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "first_name", first_name)
        pulumi.set(__self__, "last_name", last_name)
        pulumi.set(__self__, "phone", phone)
        pulumi.set(__self__, "postal_code", postal_code)
        pulumi.set(__self__, "state_province", state_province)
        if address2 is not None:
            pulumi.set(__self__, "address2", address2)
        if fax is not None:
            pulumi.set(__self__, "fax", fax)
        if job_title is not None:
            pulumi.set(__self__, "job_title", job_title)
        if label is not None:
            pulumi.set(__self__, "label", label)
        if organization_name is not None:
            pulumi.set(__self__, "organization_name", organization_name)

    @_builtins.property
    @pulumi.getter
    def address1(self) -> pulumi.Input[_builtins.str]:
        """
        The primary address line (street address, building number, etc.).
        """
        return pulumi.get(self, "address1")

    @address1.setter
    def address1(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "address1", value)

    @_builtins.property
    @pulumi.getter
    def city(self) -> pulumi.Input[_builtins.str]:
        """
        The city where the contact is located.
        """
        return pulumi.get(self, "city")

    @city.setter
    def city(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "city", value)

    @_builtins.property
    @pulumi.getter
    def country(self) -> pulumi.Input[_builtins.str]:
        """
        The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "country", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Input[_builtins.str]:
        """
        The contact's email address.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter(name="firstName")
    def first_name(self) -> pulumi.Input[_builtins.str]:
        """
        The first name of the contact person.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "first_name", value)

    @_builtins.property
    @pulumi.getter(name="lastName")
    def last_name(self) -> pulumi.Input[_builtins.str]:
        """
        The last name of the contact person.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "last_name", value)

    @_builtins.property
    @pulumi.getter
    def phone(self) -> pulumi.Input[_builtins.str]:
        """
        The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "phone", value)

    @_builtins.property
    @pulumi.getter(name="postalCode")
    def postal_code(self) -> pulumi.Input[_builtins.str]:
        """
        The postal code, ZIP code, or equivalent for the contact's location.
        """
        return pulumi.get(self, "postal_code")

    @postal_code.setter
    def postal_code(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "postal_code", value)

    @_builtins.property
    @pulumi.getter(name="stateProvince")
    def state_province(self) -> pulumi.Input[_builtins.str]:
        """
        The state, province, or region where the contact is located.
        """
        return pulumi.get(self, "state_province")

    @state_province.setter
    def state_province(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "state_province", value)

    @_builtins.property
    @pulumi.getter
    def address2(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secondary address line (apartment, suite, floor, etc.).
        """
        return pulumi.get(self, "address2")

    @address2.setter
    def address2(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address2", value)

    @_builtins.property
    @pulumi.getter
    def fax(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        """
        return pulumi.get(self, "fax")

    @fax.setter
    def fax(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fax", value)

    @_builtins.property
    @pulumi.getter(name="jobTitle")
    def job_title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The job title or position of the contact person within the organization.
        """
        return pulumi.get(self, "job_title")

    @job_title.setter
    def job_title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "job_title", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A descriptive label for the contact to help identify it.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the organization or company associated with the contact.
        """
        return pulumi.get(self, "organization_name")

    @organization_name.setter
    def organization_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_name", value)


@pulumi.input_type
class _ContactState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.int]] = None,
                 address1: Optional[pulumi.Input[_builtins.str]] = None,
                 address2: Optional[pulumi.Input[_builtins.str]] = None,
                 city: Optional[pulumi.Input[_builtins.str]] = None,
                 country: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 fax: Optional[pulumi.Input[_builtins.str]] = None,
                 fax_normalized: Optional[pulumi.Input[_builtins.str]] = None,
                 first_name: Optional[pulumi.Input[_builtins.str]] = None,
                 job_title: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 last_name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 phone: Optional[pulumi.Input[_builtins.str]] = None,
                 phone_normalized: Optional[pulumi.Input[_builtins.str]] = None,
                 postal_code: Optional[pulumi.Input[_builtins.str]] = None,
                 state_province: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Contact resources.

        :param pulumi.Input[_builtins.int] account_id: The account ID for the contact.
        :param pulumi.Input[_builtins.str] address1: The primary address line (street address, building number, etc.).
        :param pulumi.Input[_builtins.str] address2: The secondary address line (apartment, suite, floor, etc.).
        :param pulumi.Input[_builtins.str] city: The city where the contact is located.
        :param pulumi.Input[_builtins.str] country: The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        :param pulumi.Input[_builtins.str] created_at: Timestamp representing when this contact was created.
        :param pulumi.Input[_builtins.str] email: The contact's email address.
        :param pulumi.Input[_builtins.str] fax: The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        :param pulumi.Input[_builtins.str] fax_normalized: The fax number, normalized.
        :param pulumi.Input[_builtins.str] first_name: The first name of the contact person.
        :param pulumi.Input[_builtins.str] job_title: The job title or position of the contact person within the organization.
        :param pulumi.Input[_builtins.str] label: A descriptive label for the contact to help identify it.
        :param pulumi.Input[_builtins.str] last_name: The last name of the contact person.
        :param pulumi.Input[_builtins.str] organization_name: The name of the organization or company associated with the contact.
        :param pulumi.Input[_builtins.str] phone: The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        :param pulumi.Input[_builtins.str] phone_normalized: The phone number, normalized.
        :param pulumi.Input[_builtins.str] postal_code: The postal code, ZIP code, or equivalent for the contact's location.
        :param pulumi.Input[_builtins.str] state_province: The state, province, or region where the contact is located.
        :param pulumi.Input[_builtins.str] updated_at: Timestamp representing when this contact was updated.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if address1 is not None:
            pulumi.set(__self__, "address1", address1)
        if address2 is not None:
            pulumi.set(__self__, "address2", address2)
        if city is not None:
            pulumi.set(__self__, "city", city)
        if country is not None:
            pulumi.set(__self__, "country", country)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if fax is not None:
            pulumi.set(__self__, "fax", fax)
        if fax_normalized is not None:
            pulumi.set(__self__, "fax_normalized", fax_normalized)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if job_title is not None:
            pulumi.set(__self__, "job_title", job_title)
        if label is not None:
            pulumi.set(__self__, "label", label)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if organization_name is not None:
            pulumi.set(__self__, "organization_name", organization_name)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if phone_normalized is not None:
            pulumi.set(__self__, "phone_normalized", phone_normalized)
        if postal_code is not None:
            pulumi.set(__self__, "postal_code", postal_code)
        if state_province is not None:
            pulumi.set(__self__, "state_province", state_province)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The account ID for the contact.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def address1(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The primary address line (street address, building number, etc.).
        """
        return pulumi.get(self, "address1")

    @address1.setter
    def address1(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address1", value)

    @_builtins.property
    @pulumi.getter
    def address2(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secondary address line (apartment, suite, floor, etc.).
        """
        return pulumi.get(self, "address2")

    @address2.setter
    def address2(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address2", value)

    @_builtins.property
    @pulumi.getter
    def city(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The city where the contact is located.
        """
        return pulumi.get(self, "city")

    @city.setter
    def city(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "city", value)

    @_builtins.property
    @pulumi.getter
    def country(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "country", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp representing when this contact was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contact's email address.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter
    def fax(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        """
        return pulumi.get(self, "fax")

    @fax.setter
    def fax(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fax", value)

    @_builtins.property
    @pulumi.getter(name="faxNormalized")
    def fax_normalized(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fax number, normalized.
        """
        return pulumi.get(self, "fax_normalized")

    @fax_normalized.setter
    def fax_normalized(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fax_normalized", value)

    @_builtins.property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The first name of the contact person.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "first_name", value)

    @_builtins.property
    @pulumi.getter(name="jobTitle")
    def job_title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The job title or position of the contact person within the organization.
        """
        return pulumi.get(self, "job_title")

    @job_title.setter
    def job_title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "job_title", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A descriptive label for the contact to help identify it.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The last name of the contact person.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_name", value)

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the organization or company associated with the contact.
        """
        return pulumi.get(self, "organization_name")

    @organization_name.setter
    def organization_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_name", value)

    @_builtins.property
    @pulumi.getter
    def phone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "phone", value)

    @_builtins.property
    @pulumi.getter(name="phoneNormalized")
    def phone_normalized(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The phone number, normalized.
        """
        return pulumi.get(self, "phone_normalized")

    @phone_normalized.setter
    def phone_normalized(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "phone_normalized", value)

    @_builtins.property
    @pulumi.getter(name="postalCode")
    def postal_code(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The postal code, ZIP code, or equivalent for the contact's location.
        """
        return pulumi.get(self, "postal_code")

    @postal_code.setter
    def postal_code(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "postal_code", value)

    @_builtins.property
    @pulumi.getter(name="stateProvince")
    def state_province(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The state, province, or region where the contact is located.
        """
        return pulumi.get(self, "state_province")

    @state_province.setter
    def state_province(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state_province", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp representing when this contact was updated.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("dnsimple:index/contact:Contact")
class Contact(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address1: Optional[pulumi.Input[_builtins.str]] = None,
                 address2: Optional[pulumi.Input[_builtins.str]] = None,
                 city: Optional[pulumi.Input[_builtins.str]] = None,
                 country: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 fax: Optional[pulumi.Input[_builtins.str]] = None,
                 first_name: Optional[pulumi.Input[_builtins.str]] = None,
                 job_title: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 last_name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 phone: Optional[pulumi.Input[_builtins.str]] = None,
                 postal_code: Optional[pulumi.Input[_builtins.str]] = None,
                 state_province: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a DNSimple contact resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        example = dnsimple.Contact("example",
            label="Main Contact",
            first_name="John",
            last_name="Doe",
            organization_name="Example Inc",
            job_title="Manager",
            address1="123 Main Street",
            address2="Suite 100",
            city="San Francisco",
            state_province="California",
            postal_code="94105",
            country="US",
            phone="+1.4155551234",
            fax="+1.4155555678",
            email="john@example.com")
        ```

        ## Import

        DNSimple contacts can be imported using their numeric ID.

        ```sh
        $ pulumi import dnsimple:index/contact:Contact example 5678
        ```

        The contact ID can be found within the [DNSimple Contacts API](https://developer.dnsimple.com/v2/contacts/#listContacts). Check out [Authentication](https://developer.dnsimple.com/v2/#authentication) in API Overview for available options.


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] address1: The primary address line (street address, building number, etc.).
        :param pulumi.Input[_builtins.str] address2: The secondary address line (apartment, suite, floor, etc.).
        :param pulumi.Input[_builtins.str] city: The city where the contact is located.
        :param pulumi.Input[_builtins.str] country: The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        :param pulumi.Input[_builtins.str] email: The contact's email address.
        :param pulumi.Input[_builtins.str] fax: The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        :param pulumi.Input[_builtins.str] first_name: The first name of the contact person.
        :param pulumi.Input[_builtins.str] job_title: The job title or position of the contact person within the organization.
        :param pulumi.Input[_builtins.str] label: A descriptive label for the contact to help identify it.
        :param pulumi.Input[_builtins.str] last_name: The last name of the contact person.
        :param pulumi.Input[_builtins.str] organization_name: The name of the organization or company associated with the contact.
        :param pulumi.Input[_builtins.str] phone: The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        :param pulumi.Input[_builtins.str] postal_code: The postal code, ZIP code, or equivalent for the contact's location.
        :param pulumi.Input[_builtins.str] state_province: The state, province, or region where the contact is located.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ContactArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DNSimple contact resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        example = dnsimple.Contact("example",
            label="Main Contact",
            first_name="John",
            last_name="Doe",
            organization_name="Example Inc",
            job_title="Manager",
            address1="123 Main Street",
            address2="Suite 100",
            city="San Francisco",
            state_province="California",
            postal_code="94105",
            country="US",
            phone="+1.4155551234",
            fax="+1.4155555678",
            email="john@example.com")
        ```

        ## Import

        DNSimple contacts can be imported using their numeric ID.

        ```sh
        $ pulumi import dnsimple:index/contact:Contact example 5678
        ```

        The contact ID can be found within the [DNSimple Contacts API](https://developer.dnsimple.com/v2/contacts/#listContacts). Check out [Authentication](https://developer.dnsimple.com/v2/#authentication) in API Overview for available options.


        :param str resource_name: The name of the resource.
        :param ContactArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContactArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address1: Optional[pulumi.Input[_builtins.str]] = None,
                 address2: Optional[pulumi.Input[_builtins.str]] = None,
                 city: Optional[pulumi.Input[_builtins.str]] = None,
                 country: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 fax: Optional[pulumi.Input[_builtins.str]] = None,
                 first_name: Optional[pulumi.Input[_builtins.str]] = None,
                 job_title: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 last_name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 phone: Optional[pulumi.Input[_builtins.str]] = None,
                 postal_code: Optional[pulumi.Input[_builtins.str]] = None,
                 state_province: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContactArgs.__new__(ContactArgs)

            if address1 is None and not opts.urn:
                raise TypeError("Missing required property 'address1'")
            __props__.__dict__["address1"] = address1
            __props__.__dict__["address2"] = address2
            if city is None and not opts.urn:
                raise TypeError("Missing required property 'city'")
            __props__.__dict__["city"] = city
            if country is None and not opts.urn:
                raise TypeError("Missing required property 'country'")
            __props__.__dict__["country"] = country
            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["fax"] = fax
            if first_name is None and not opts.urn:
                raise TypeError("Missing required property 'first_name'")
            __props__.__dict__["first_name"] = first_name
            __props__.__dict__["job_title"] = job_title
            __props__.__dict__["label"] = label
            if last_name is None and not opts.urn:
                raise TypeError("Missing required property 'last_name'")
            __props__.__dict__["last_name"] = last_name
            __props__.__dict__["organization_name"] = organization_name
            if phone is None and not opts.urn:
                raise TypeError("Missing required property 'phone'")
            __props__.__dict__["phone"] = phone
            if postal_code is None and not opts.urn:
                raise TypeError("Missing required property 'postal_code'")
            __props__.__dict__["postal_code"] = postal_code
            if state_province is None and not opts.urn:
                raise TypeError("Missing required property 'state_province'")
            __props__.__dict__["state_province"] = state_province
            __props__.__dict__["account_id"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["fax_normalized"] = None
            __props__.__dict__["phone_normalized"] = None
            __props__.__dict__["updated_at"] = None
        super(Contact, __self__).__init__(
            'dnsimple:index/contact:Contact',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.int]] = None,
            address1: Optional[pulumi.Input[_builtins.str]] = None,
            address2: Optional[pulumi.Input[_builtins.str]] = None,
            city: Optional[pulumi.Input[_builtins.str]] = None,
            country: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            email: Optional[pulumi.Input[_builtins.str]] = None,
            fax: Optional[pulumi.Input[_builtins.str]] = None,
            fax_normalized: Optional[pulumi.Input[_builtins.str]] = None,
            first_name: Optional[pulumi.Input[_builtins.str]] = None,
            job_title: Optional[pulumi.Input[_builtins.str]] = None,
            label: Optional[pulumi.Input[_builtins.str]] = None,
            last_name: Optional[pulumi.Input[_builtins.str]] = None,
            organization_name: Optional[pulumi.Input[_builtins.str]] = None,
            phone: Optional[pulumi.Input[_builtins.str]] = None,
            phone_normalized: Optional[pulumi.Input[_builtins.str]] = None,
            postal_code: Optional[pulumi.Input[_builtins.str]] = None,
            state_province: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'Contact':
        """
        Get an existing Contact resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] account_id: The account ID for the contact.
        :param pulumi.Input[_builtins.str] address1: The primary address line (street address, building number, etc.).
        :param pulumi.Input[_builtins.str] address2: The secondary address line (apartment, suite, floor, etc.).
        :param pulumi.Input[_builtins.str] city: The city where the contact is located.
        :param pulumi.Input[_builtins.str] country: The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        :param pulumi.Input[_builtins.str] created_at: Timestamp representing when this contact was created.
        :param pulumi.Input[_builtins.str] email: The contact's email address.
        :param pulumi.Input[_builtins.str] fax: The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        :param pulumi.Input[_builtins.str] fax_normalized: The fax number, normalized.
        :param pulumi.Input[_builtins.str] first_name: The first name of the contact person.
        :param pulumi.Input[_builtins.str] job_title: The job title or position of the contact person within the organization.
        :param pulumi.Input[_builtins.str] label: A descriptive label for the contact to help identify it.
        :param pulumi.Input[_builtins.str] last_name: The last name of the contact person.
        :param pulumi.Input[_builtins.str] organization_name: The name of the organization or company associated with the contact.
        :param pulumi.Input[_builtins.str] phone: The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        :param pulumi.Input[_builtins.str] phone_normalized: The phone number, normalized.
        :param pulumi.Input[_builtins.str] postal_code: The postal code, ZIP code, or equivalent for the contact's location.
        :param pulumi.Input[_builtins.str] state_province: The state, province, or region where the contact is located.
        :param pulumi.Input[_builtins.str] updated_at: Timestamp representing when this contact was updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContactState.__new__(_ContactState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["address1"] = address1
        __props__.__dict__["address2"] = address2
        __props__.__dict__["city"] = city
        __props__.__dict__["country"] = country
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["email"] = email
        __props__.__dict__["fax"] = fax
        __props__.__dict__["fax_normalized"] = fax_normalized
        __props__.__dict__["first_name"] = first_name
        __props__.__dict__["job_title"] = job_title
        __props__.__dict__["label"] = label
        __props__.__dict__["last_name"] = last_name
        __props__.__dict__["organization_name"] = organization_name
        __props__.__dict__["phone"] = phone
        __props__.__dict__["phone_normalized"] = phone_normalized
        __props__.__dict__["postal_code"] = postal_code
        __props__.__dict__["state_province"] = state_province
        __props__.__dict__["updated_at"] = updated_at
        return Contact(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.int]:
        """
        The account ID for the contact.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def address1(self) -> pulumi.Output[_builtins.str]:
        """
        The primary address line (street address, building number, etc.).
        """
        return pulumi.get(self, "address1")

    @_builtins.property
    @pulumi.getter
    def address2(self) -> pulumi.Output[_builtins.str]:
        """
        The secondary address line (apartment, suite, floor, etc.).
        """
        return pulumi.get(self, "address2")

    @_builtins.property
    @pulumi.getter
    def city(self) -> pulumi.Output[_builtins.str]:
        """
        The city where the contact is located.
        """
        return pulumi.get(self, "city")

    @_builtins.property
    @pulumi.getter
    def country(self) -> pulumi.Output[_builtins.str]:
        """
        The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        """
        return pulumi.get(self, "country")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp representing when this contact was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Output[_builtins.str]:
        """
        The contact's email address.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter
    def fax(self) -> pulumi.Output[_builtins.str]:
        """
        The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        """
        return pulumi.get(self, "fax")

    @_builtins.property
    @pulumi.getter(name="faxNormalized")
    def fax_normalized(self) -> pulumi.Output[_builtins.str]:
        """
        The fax number, normalized.
        """
        return pulumi.get(self, "fax_normalized")

    @_builtins.property
    @pulumi.getter(name="firstName")
    def first_name(self) -> pulumi.Output[_builtins.str]:
        """
        The first name of the contact person.
        """
        return pulumi.get(self, "first_name")

    @_builtins.property
    @pulumi.getter(name="jobTitle")
    def job_title(self) -> pulumi.Output[_builtins.str]:
        """
        The job title or position of the contact person within the organization.
        """
        return pulumi.get(self, "job_title")

    @_builtins.property
    @pulumi.getter
    def label(self) -> pulumi.Output[_builtins.str]:
        """
        A descriptive label for the contact to help identify it.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter(name="lastName")
    def last_name(self) -> pulumi.Output[_builtins.str]:
        """
        The last name of the contact person.
        """
        return pulumi.get(self, "last_name")

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the organization or company associated with the contact.
        """
        return pulumi.get(self, "organization_name")

    @_builtins.property
    @pulumi.getter
    def phone(self) -> pulumi.Output[_builtins.str]:
        """
        The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        """
        return pulumi.get(self, "phone")

    @_builtins.property
    @pulumi.getter(name="phoneNormalized")
    def phone_normalized(self) -> pulumi.Output[_builtins.str]:
        """
        The phone number, normalized.
        """
        return pulumi.get(self, "phone_normalized")

    @_builtins.property
    @pulumi.getter(name="postalCode")
    def postal_code(self) -> pulumi.Output[_builtins.str]:
        """
        The postal code, ZIP code, or equivalent for the contact's location.
        """
        return pulumi.get(self, "postal_code")

    @_builtins.property
    @pulumi.getter(name="stateProvince")
    def state_province(self) -> pulumi.Output[_builtins.str]:
        """
        The state, province, or region where the contact is located.
        """
        return pulumi.get(self, "state_province")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp representing when this contact was updated.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetRegistrantChangeCheckResult',
    'AwaitableGetRegistrantChangeCheckResult',
    'get_registrant_change_check',
    'get_registrant_change_check_output',
]

@pulumi.output_type
class GetRegistrantChangeCheckResult:
    """
    A collection of values returned by getRegistrantChangeCheck.
    """
    def __init__(__self__, contact_id=None, domain_id=None, extended_attributes=None, id=None, registry_owner_change=None):
        if contact_id and not isinstance(contact_id, str):
            raise TypeError("Expected argument 'contact_id' to be a str")
        pulumi.set(__self__, "contact_id", contact_id)
        if domain_id and not isinstance(domain_id, str):
            raise TypeError("Expected argument 'domain_id' to be a str")
        pulumi.set(__self__, "domain_id", domain_id)
        if extended_attributes and not isinstance(extended_attributes, list):
            raise TypeError("Expected argument 'extended_attributes' to be a list")
        pulumi.set(__self__, "extended_attributes", extended_attributes)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if registry_owner_change and not isinstance(registry_owner_change, bool):
            raise TypeError("Expected argument 'registry_owner_change' to be a bool")
        pulumi.set(__self__, "registry_owner_change", registry_owner_change)

    @_builtins.property
    @pulumi.getter(name="contactId")
    def contact_id(self) -> _builtins.str:
        """
        The ID of the contact you are planning to change to.
        """
        return pulumi.get(self, "contact_id")

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> _builtins.str:
        """
        The name or ID of the domain.
        """
        return pulumi.get(self, "domain_id")

    @_builtins.property
    @pulumi.getter(name="extendedAttributes")
    def extended_attributes(self) -> Sequence['outputs.GetRegistrantChangeCheckExtendedAttributeResult']:
        """
        (List) A list of extended attributes that are required for the registrant change. (see below for nested schema)
        """
        return pulumi.get(self, "extended_attributes")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="registryOwnerChange")
    def registry_owner_change(self) -> _builtins.bool:
        """
        (Boolean) Whether the registrant change is going to result in an owner change at the registry.
        """
        return pulumi.get(self, "registry_owner_change")


class AwaitableGetRegistrantChangeCheckResult(GetRegistrantChangeCheckResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRegistrantChangeCheckResult(
            contact_id=self.contact_id,
            domain_id=self.domain_id,
            extended_attributes=self.extended_attributes,
            id=self.id,
            registry_owner_change=self.registry_owner_change)


def get_registrant_change_check(contact_id: Optional[_builtins.str] = None,
                                domain_id: Optional[_builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRegistrantChangeCheckResult:
    """
    Get information on the requirements of a registrant change.

    > **Note:** The registrant change API is currently in developer preview and is subject to change.

    ## Example Usage

    Get registrant change requirements for the `example.com` domain and the contact with ID `1234`:

    ```python
    import pulumi
    import pulumi_dnsimple as dnsimple

    example = dnsimple.get_registrant_change_check(domain_id="example.com",
        contact_id="1234")
    ```


    :param _builtins.str contact_id: The ID of the contact you are planning to change to.
    :param _builtins.str domain_id: The name or ID of the domain.
    """
    __args__ = dict()
    __args__['contactId'] = contact_id
    __args__['domainId'] = domain_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('dnsimple:index/getRegistrantChangeCheck:getRegistrantChangeCheck', __args__, opts=opts, typ=GetRegistrantChangeCheckResult).value

    return AwaitableGetRegistrantChangeCheckResult(
        contact_id=pulumi.get(__ret__, 'contact_id'),
        domain_id=pulumi.get(__ret__, 'domain_id'),
        extended_attributes=pulumi.get(__ret__, 'extended_attributes'),
        id=pulumi.get(__ret__, 'id'),
        registry_owner_change=pulumi.get(__ret__, 'registry_owner_change'))
def get_registrant_change_check_output(contact_id: Optional[pulumi.Input[_builtins.str]] = None,
                                       domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRegistrantChangeCheckResult]:
    """
    Get information on the requirements of a registrant change.

    > **Note:** The registrant change API is currently in developer preview and is subject to change.

    ## Example Usage

    Get registrant change requirements for the `example.com` domain and the contact with ID `1234`:

    ```python
    import pulumi
    import pulumi_dnsimple as dnsimple

    example = dnsimple.get_registrant_change_check(domain_id="example.com",
        contact_id="1234")
    ```


    :param _builtins.str contact_id: The ID of the contact you are planning to change to.
    :param _builtins.str domain_id: The name or ID of the domain.
    """
    __args__ = dict()
    __args__['contactId'] = contact_id
    __args__['domainId'] = domain_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('dnsimple:index/getRegistrantChangeCheck:getRegistrantChangeCheck', __args__, opts=opts, typ=GetRegistrantChangeCheckResult)
    return __ret__.apply(lambda __response__: GetRegistrantChangeCheckResult(
        contact_id=pulumi.get(__response__, 'contact_id'),
        domain_id=pulumi.get(__response__, 'domain_id'),
        extended_attributes=pulumi.get(__response__, 'extended_attributes'),
        id=pulumi.get(__response__, 'id'),
        registry_owner_change=pulumi.get(__response__, 'registry_owner_change')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

account: Optional[str]
"""
The account for API operations.
"""

debugTransportFile: Optional[str]
"""
File path to enable HTTP request/response debugging. When set, all HTTP requests and responses will be logged to this file.
"""

prefetch: Optional[bool]
"""
Flag to enable the prefetch of zone records.
"""

sandbox: Optional[bool]
"""
Flag to enable the sandbox API.
"""

token: Optional[str]
"""
The API v2 token for API operations.
"""

userAgent: Optional[str]
"""
Custom string to append to the user agent used for sending HTTP requests to the API.
"""




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import pulumi
from enum import Enum

__all__ = [
    'RecordTypes',
]


@pulumi.type_token("dnsimple:index:RecordTypes")
class RecordTypes(_builtins.str, Enum):
    """
    DNS Record types.
    """
    A = "A"
    AAAA = "AAAA"
    ALIAS = "ALIAS"
    CAA = "CAA"
    CNAME = "CNAME"
    HINFO = "HINFO"
    MX = "MX"
    NAPTR = "NAPTR"
    NS = "NS"
    POOL = "POOL"
    PTR = "PTR"
    SPF = "SPF"
    SRV = "SRV"
    SSHFP = "SSHFP"
    TXT = "TXT"
    URL = "URL"



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RegisteredDomainArgs', 'RegisteredDomain']

@pulumi.input_type
class RegisteredDomainArgs:
    def __init__(__self__, *,
                 contact_id: pulumi.Input[_builtins.int],
                 name: pulumi.Input[_builtins.str],
                 auto_renew_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 dnssec_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 extended_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 premium_price: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['RegisteredDomainTimeoutsArgs']] = None,
                 transfer_lock_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 whois_privacy_enabled: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a RegisteredDomain resource.

        :param pulumi.Input[_builtins.int] contact_id: The ID of the contact to be used for the domain registration. The contact ID can be changed after the domain has been registered. The change will result in a new registrant change, which may result in a [60-day lock](https://support.dnsimple.com/articles/icann-60-day-lock-registrant-change/).
        :param pulumi.Input[_builtins.str] name: The domain name to be registered.
        :param pulumi.Input[_builtins.bool] auto_renew_enabled: Whether the domain should be set to auto-renew (default: `false`).
        :param pulumi.Input[_builtins.bool] dnssec_enabled: Whether the domain should have DNSSEC enabled (default: `false`).
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] extended_attributes: A map of extended attributes to be set for the domain registration. To see if there are any required extended attributes for any TLD use our [Lists the TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes). The values provided in the `extended_attributes` will also be sent when a registrant change is initiated as part of changing the `contact_id`.
        :param pulumi.Input[_builtins.str] premium_price: The premium price for the domain registration. This is only required if the domain is a premium domain. You can use our [Check domain API](https://developer.dnsimple.com/v2/registrar/#checkDomain) to check if a domain is premium and [Retrieve domain prices API](https://developer.dnsimple.com/v2/registrar/#getDomainPrices) to retrieve the premium price for a domain.
        :param pulumi.Input['RegisteredDomainTimeoutsArgs'] timeouts: (see below for nested schema).
        :param pulumi.Input[_builtins.bool] transfer_lock_enabled: Whether the domain transfer lock protection is enabled (default: `true`).
        :param pulumi.Input[_builtins.bool] whois_privacy_enabled: Whether the domain should have WHOIS privacy enabled (default: `false`).
        """
        pulumi.set(__self__, "contact_id", contact_id)
        pulumi.set(__self__, "name", name)
        if auto_renew_enabled is not None:
            pulumi.set(__self__, "auto_renew_enabled", auto_renew_enabled)
        if dnssec_enabled is not None:
            pulumi.set(__self__, "dnssec_enabled", dnssec_enabled)
        if extended_attributes is not None:
            pulumi.set(__self__, "extended_attributes", extended_attributes)
        if premium_price is not None:
            pulumi.set(__self__, "premium_price", premium_price)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)
        if transfer_lock_enabled is not None:
            pulumi.set(__self__, "transfer_lock_enabled", transfer_lock_enabled)
        if whois_privacy_enabled is not None:
            pulumi.set(__self__, "whois_privacy_enabled", whois_privacy_enabled)

    @_builtins.property
    @pulumi.getter(name="contactId")
    def contact_id(self) -> pulumi.Input[_builtins.int]:
        """
        The ID of the contact to be used for the domain registration. The contact ID can be changed after the domain has been registered. The change will result in a new registrant change, which may result in a [60-day lock](https://support.dnsimple.com/articles/icann-60-day-lock-registrant-change/).
        """
        return pulumi.get(self, "contact_id")

    @contact_id.setter
    def contact_id(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "contact_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        The domain name to be registered.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="autoRenewEnabled")
    def auto_renew_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the domain should be set to auto-renew (default: `false`).
        """
        return pulumi.get(self, "auto_renew_enabled")

    @auto_renew_enabled.setter
    def auto_renew_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_renew_enabled", value)

    @_builtins.property
    @pulumi.getter(name="dnssecEnabled")
    def dnssec_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the domain should have DNSSEC enabled (default: `false`).
        """
        return pulumi.get(self, "dnssec_enabled")

    @dnssec_enabled.setter
    def dnssec_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dnssec_enabled", value)

    @_builtins.property
    @pulumi.getter(name="extendedAttributes")
    def extended_attributes(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map of extended attributes to be set for the domain registration. To see if there are any required extended attributes for any TLD use our [Lists the TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes). The values provided in the `extended_attributes` will also be sent when a registrant change is initiated as part of changing the `contact_id`.
        """
        return pulumi.get(self, "extended_attributes")

    @extended_attributes.setter
    def extended_attributes(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "extended_attributes", value)

    @_builtins.property
    @pulumi.getter(name="premiumPrice")
    def premium_price(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The premium price for the domain registration. This is only required if the domain is a premium domain. You can use our [Check domain API](https://developer.dnsimple.com/v2/registrar/#checkDomain) to check if a domain is premium and [Retrieve domain prices API](https://developer.dnsimple.com/v2/registrar/#getDomainPrices) to retrieve the premium price for a domain.
        """
        return pulumi.get(self, "premium_price")

    @premium_price.setter
    def premium_price(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "premium_price", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['RegisteredDomainTimeoutsArgs']]:
        """
        (see below for nested schema).
        """
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['RegisteredDomainTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)

    @_builtins.property
    @pulumi.getter(name="transferLockEnabled")
    def transfer_lock_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the domain transfer lock protection is enabled (default: `true`).
        """
        return pulumi.get(self, "transfer_lock_enabled")

    @transfer_lock_enabled.setter
    def transfer_lock_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "transfer_lock_enabled", value)

    @_builtins.property
    @pulumi.getter(name="whoisPrivacyEnabled")
    def whois_privacy_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the domain should have WHOIS privacy enabled (default: `false`).
        """
        return pulumi.get(self, "whois_privacy_enabled")

    @whois_privacy_enabled.setter
    def whois_privacy_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "whois_privacy_enabled", value)


@pulumi.input_type
class _RegisteredDomainState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.int]] = None,
                 auto_renew_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 contact_id: Optional[pulumi.Input[_builtins.int]] = None,
                 dnssec_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_registration: Optional[pulumi.Input['RegisteredDomainDomainRegistrationArgs']] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 extended_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 premium_price: Optional[pulumi.Input[_builtins.str]] = None,
                 registrant_change: Optional[pulumi.Input['RegisteredDomainRegistrantChangeArgs']] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['RegisteredDomainTimeoutsArgs']] = None,
                 transfer_lock_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 unicode_name: Optional[pulumi.Input[_builtins.str]] = None,
                 whois_privacy_enabled: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering RegisteredDomain resources.

        :param pulumi.Input[_builtins.bool] auto_renew_enabled: Whether the domain should be set to auto-renew (default: `false`).
        :param pulumi.Input[_builtins.int] contact_id: The ID of the contact to be used for the domain registration. The contact ID can be changed after the domain has been registered. The change will result in a new registrant change, which may result in a [60-day lock](https://support.dnsimple.com/articles/icann-60-day-lock-registrant-change/).
        :param pulumi.Input[_builtins.bool] dnssec_enabled: Whether the domain should have DNSSEC enabled (default: `false`).
        :param pulumi.Input['RegisteredDomainDomainRegistrationArgs'] domain_registration: The domain registration details. (see below for nested schema)
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] extended_attributes: A map of extended attributes to be set for the domain registration. To see if there are any required extended attributes for any TLD use our [Lists the TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes). The values provided in the `extended_attributes` will also be sent when a registrant change is initiated as part of changing the `contact_id`.
        :param pulumi.Input[_builtins.str] name: The domain name to be registered.
        :param pulumi.Input[_builtins.str] premium_price: The premium price for the domain registration. This is only required if the domain is a premium domain. You can use our [Check domain API](https://developer.dnsimple.com/v2/registrar/#checkDomain) to check if a domain is premium and [Retrieve domain prices API](https://developer.dnsimple.com/v2/registrar/#getDomainPrices) to retrieve the premium price for a domain.
        :param pulumi.Input['RegisteredDomainRegistrantChangeArgs'] registrant_change: The registrant change details.
        :param pulumi.Input[_builtins.str] state: (String) - The state of the domain registration.
        :param pulumi.Input['RegisteredDomainTimeoutsArgs'] timeouts: (see below for nested schema).
        :param pulumi.Input[_builtins.bool] transfer_lock_enabled: Whether the domain transfer lock protection is enabled (default: `true`).
        :param pulumi.Input[_builtins.str] unicode_name: The domain name in Unicode format.
        :param pulumi.Input[_builtins.bool] whois_privacy_enabled: Whether the domain should have WHOIS privacy enabled (default: `false`).
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if auto_renew_enabled is not None:
            pulumi.set(__self__, "auto_renew_enabled", auto_renew_enabled)
        if contact_id is not None:
            pulumi.set(__self__, "contact_id", contact_id)
        if dnssec_enabled is not None:
            pulumi.set(__self__, "dnssec_enabled", dnssec_enabled)
        if domain_registration is not None:
            pulumi.set(__self__, "domain_registration", domain_registration)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if extended_attributes is not None:
            pulumi.set(__self__, "extended_attributes", extended_attributes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if premium_price is not None:
            pulumi.set(__self__, "premium_price", premium_price)
        if registrant_change is not None:
            pulumi.set(__self__, "registrant_change", registrant_change)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)
        if transfer_lock_enabled is not None:
            pulumi.set(__self__, "transfer_lock_enabled", transfer_lock_enabled)
        if unicode_name is not None:
            pulumi.set(__self__, "unicode_name", unicode_name)
        if whois_privacy_enabled is not None:
            pulumi.set(__self__, "whois_privacy_enabled", whois_privacy_enabled)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="autoRenewEnabled")
    def auto_renew_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the domain should be set to auto-renew (default: `false`).
        """
        return pulumi.get(self, "auto_renew_enabled")

    @auto_renew_enabled.setter
    def auto_renew_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_renew_enabled", value)

    @_builtins.property
    @pulumi.getter(name="contactId")
    def contact_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the contact to be used for the domain registration. The contact ID can be changed after the domain has been registered. The change will result in a new registrant change, which may result in a [60-day lock](https://support.dnsimple.com/articles/icann-60-day-lock-registrant-change/).
        """
        return pulumi.get(self, "contact_id")

    @contact_id.setter
    def contact_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "contact_id", value)

    @_builtins.property
    @pulumi.getter(name="dnssecEnabled")
    def dnssec_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the domain should have DNSSEC enabled (default: `false`).
        """
        return pulumi.get(self, "dnssec_enabled")

    @dnssec_enabled.setter
    def dnssec_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dnssec_enabled", value)

    @_builtins.property
    @pulumi.getter(name="domainRegistration")
    def domain_registration(self) -> Optional[pulumi.Input['RegisteredDomainDomainRegistrationArgs']]:
        """
        The domain registration details. (see below for nested schema)
        """
        return pulumi.get(self, "domain_registration")

    @domain_registration.setter
    def domain_registration(self, value: Optional[pulumi.Input['RegisteredDomainDomainRegistrationArgs']]):
        pulumi.set(self, "domain_registration", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter(name="extendedAttributes")
    def extended_attributes(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map of extended attributes to be set for the domain registration. To see if there are any required extended attributes for any TLD use our [Lists the TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes). The values provided in the `extended_attributes` will also be sent when a registrant change is initiated as part of changing the `contact_id`.
        """
        return pulumi.get(self, "extended_attributes")

    @extended_attributes.setter
    def extended_attributes(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "extended_attributes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain name to be registered.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="premiumPrice")
    def premium_price(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The premium price for the domain registration. This is only required if the domain is a premium domain. You can use our [Check domain API](https://developer.dnsimple.com/v2/registrar/#checkDomain) to check if a domain is premium and [Retrieve domain prices API](https://developer.dnsimple.com/v2/registrar/#getDomainPrices) to retrieve the premium price for a domain.
        """
        return pulumi.get(self, "premium_price")

    @premium_price.setter
    def premium_price(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "premium_price", value)

    @_builtins.property
    @pulumi.getter(name="registrantChange")
    def registrant_change(self) -> Optional[pulumi.Input['RegisteredDomainRegistrantChangeArgs']]:
        """
        The registrant change details.
        """
        return pulumi.get(self, "registrant_change")

    @registrant_change.setter
    def registrant_change(self, value: Optional[pulumi.Input['RegisteredDomainRegistrantChangeArgs']]):
        pulumi.set(self, "registrant_change", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (String) - The state of the domain registration.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['RegisteredDomainTimeoutsArgs']]:
        """
        (see below for nested schema).
        """
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['RegisteredDomainTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)

    @_builtins.property
    @pulumi.getter(name="transferLockEnabled")
    def transfer_lock_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the domain transfer lock protection is enabled (default: `true`).
        """
        return pulumi.get(self, "transfer_lock_enabled")

    @transfer_lock_enabled.setter
    def transfer_lock_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "transfer_lock_enabled", value)

    @_builtins.property
    @pulumi.getter(name="unicodeName")
    def unicode_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain name in Unicode format.
        """
        return pulumi.get(self, "unicode_name")

    @unicode_name.setter
    def unicode_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "unicode_name", value)

    @_builtins.property
    @pulumi.getter(name="whoisPrivacyEnabled")
    def whois_privacy_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the domain should have WHOIS privacy enabled (default: `false`).
        """
        return pulumi.get(self, "whois_privacy_enabled")

    @whois_privacy_enabled.setter
    def whois_privacy_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "whois_privacy_enabled", value)


@pulumi.type_token("dnsimple:index/registeredDomain:RegisteredDomain")
class RegisteredDomain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 contact_id: Optional[pulumi.Input[_builtins.int]] = None,
                 dnssec_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 extended_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 premium_price: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['RegisteredDomainTimeoutsArgs', 'RegisteredDomainTimeoutsArgsDict']]] = None,
                 transfer_lock_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 whois_privacy_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Provides a DNSimple registered domain resource.

        ## Example Usage

        The simplest example below requires a contact (existing or a new one to be created) and basic domain information.

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        alice_main = dnsimple.Contact("alice_main",
            label="Alice",
            first_name="Alice",
            last_name="Appleseed",
            organization_name="Contoso",
            job_title="Manager",
            address1="Level 1, 2 Main St",
            city="San Francisco",
            state_province="California",
            postal_code="90210",
            country="US",
            phone="+1.401239523",
            email="apple@contoso.com")
        example_com = dnsimple.RegisteredDomain("example_com",
            name="example.com",
            contact_id=alice_main.id)
        ```

        ### Example with more settings

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        example_com = dnsimple.RegisteredDomain("example_com",
            name="example.com",
            contact_id=alice_main["id"],
            auto_renew_enabled=True,
            transfer_lock_enabled=True,
            whois_privacy_enabled=True,
            dnssec_enabled=False)
        ```

        ### Example with extended attributes

        Some domain extensions require additional information during registration. You can check if a domain extension requires extended attributes using the [TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes).

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        example_bio = dnsimple.RegisteredDomain("example_bio",
            name="example.bio",
            contact_id=alice_main["id"],
            auto_renew_enabled=True,
            extended_attributes={
                "bio_agree": "I Agree",
            })
        ```

        ## Import

        DNSimple registered domains can be imported using their domain name and **optionally** with domain registration ID.

        **Importing registered domain example.com:**

        ```sh
        $ pulumi import dnsimple:index/registeredDomain:RegisteredDomain example example.com
        ```

        **Importing registered domain example.com with domain registration ID 1234:**

        ```sh
        $ pulumi import dnsimple:index/registeredDomain:RegisteredDomain example example.com_1234
        ```

        > **Note:** At present there is no way to retrieve the domain registration ID from the DNSimple API or UI. You will need to have noted the ID when you created the domain registration. Prefer using the domain name only when importing.


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] auto_renew_enabled: Whether the domain should be set to auto-renew (default: `false`).
        :param pulumi.Input[_builtins.int] contact_id: The ID of the contact to be used for the domain registration. The contact ID can be changed after the domain has been registered. The change will result in a new registrant change, which may result in a [60-day lock](https://support.dnsimple.com/articles/icann-60-day-lock-registrant-change/).
        :param pulumi.Input[_builtins.bool] dnssec_enabled: Whether the domain should have DNSSEC enabled (default: `false`).
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] extended_attributes: A map of extended attributes to be set for the domain registration. To see if there are any required extended attributes for any TLD use our [Lists the TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes). The values provided in the `extended_attributes` will also be sent when a registrant change is initiated as part of changing the `contact_id`.
        :param pulumi.Input[_builtins.str] name: The domain name to be registered.
        :param pulumi.Input[_builtins.str] premium_price: The premium price for the domain registration. This is only required if the domain is a premium domain. You can use our [Check domain API](https://developer.dnsimple.com/v2/registrar/#checkDomain) to check if a domain is premium and [Retrieve domain prices API](https://developer.dnsimple.com/v2/registrar/#getDomainPrices) to retrieve the premium price for a domain.
        :param pulumi.Input[Union['RegisteredDomainTimeoutsArgs', 'RegisteredDomainTimeoutsArgsDict']] timeouts: (see below for nested schema).
        :param pulumi.Input[_builtins.bool] transfer_lock_enabled: Whether the domain transfer lock protection is enabled (default: `true`).
        :param pulumi.Input[_builtins.bool] whois_privacy_enabled: Whether the domain should have WHOIS privacy enabled (default: `false`).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RegisteredDomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DNSimple registered domain resource.

        ## Example Usage

        The simplest example below requires a contact (existing or a new one to be created) and basic domain information.

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        alice_main = dnsimple.Contact("alice_main",
            label="Alice",
            first_name="Alice",
            last_name="Appleseed",
            organization_name="Contoso",
            job_title="Manager",
            address1="Level 1, 2 Main St",
            city="San Francisco",
            state_province="California",
            postal_code="90210",
            country="US",
            phone="+1.401239523",
            email="apple@contoso.com")
        example_com = dnsimple.RegisteredDomain("example_com",
            name="example.com",
            contact_id=alice_main.id)
        ```

        ### Example with more settings

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        example_com = dnsimple.RegisteredDomain("example_com",
            name="example.com",
            contact_id=alice_main["id"],
            auto_renew_enabled=True,
            transfer_lock_enabled=True,
            whois_privacy_enabled=True,
            dnssec_enabled=False)
        ```

        ### Example with extended attributes

        Some domain extensions require additional information during registration. You can check if a domain extension requires extended attributes using the [TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes).

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        example_bio = dnsimple.RegisteredDomain("example_bio",
            name="example.bio",
            contact_id=alice_main["id"],
            auto_renew_enabled=True,
            extended_attributes={
                "bio_agree": "I Agree",
            })
        ```

        ## Import

        DNSimple registered domains can be imported using their domain name and **optionally** with domain registration ID.

        **Importing registered domain example.com:**

        ```sh
        $ pulumi import dnsimple:index/registeredDomain:RegisteredDomain example example.com
        ```

        **Importing registered domain example.com with domain registration ID 1234:**

        ```sh
        $ pulumi import dnsimple:index/registeredDomain:RegisteredDomain example example.com_1234
        ```

        > **Note:** At present there is no way to retrieve the domain registration ID from the DNSimple API or UI. You will need to have noted the ID when you created the domain registration. Prefer using the domain name only when importing.


        :param str resource_name: The name of the resource.
        :param RegisteredDomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RegisteredDomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 contact_id: Optional[pulumi.Input[_builtins.int]] = None,
                 dnssec_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 extended_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 premium_price: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['RegisteredDomainTimeoutsArgs', 'RegisteredDomainTimeoutsArgsDict']]] = None,
                 transfer_lock_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 whois_privacy_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RegisteredDomainArgs.__new__(RegisteredDomainArgs)

            __props__.__dict__["auto_renew_enabled"] = auto_renew_enabled
            if contact_id is None and not opts.urn:
                raise TypeError("Missing required property 'contact_id'")
            __props__.__dict__["contact_id"] = contact_id
            __props__.__dict__["dnssec_enabled"] = dnssec_enabled
            __props__.__dict__["extended_attributes"] = extended_attributes
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["premium_price"] = premium_price
            __props__.__dict__["timeouts"] = timeouts
            __props__.__dict__["transfer_lock_enabled"] = transfer_lock_enabled
            __props__.__dict__["whois_privacy_enabled"] = whois_privacy_enabled
            __props__.__dict__["account_id"] = None
            __props__.__dict__["domain_registration"] = None
            __props__.__dict__["expires_at"] = None
            __props__.__dict__["registrant_change"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["unicode_name"] = None
        super(RegisteredDomain, __self__).__init__(
            'dnsimple:index/registeredDomain:RegisteredDomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.int]] = None,
            auto_renew_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            contact_id: Optional[pulumi.Input[_builtins.int]] = None,
            dnssec_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            domain_registration: Optional[pulumi.Input[Union['RegisteredDomainDomainRegistrationArgs', 'RegisteredDomainDomainRegistrationArgsDict']]] = None,
            expires_at: Optional[pulumi.Input[_builtins.str]] = None,
            extended_attributes: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            premium_price: Optional[pulumi.Input[_builtins.str]] = None,
            registrant_change: Optional[pulumi.Input[Union['RegisteredDomainRegistrantChangeArgs', 'RegisteredDomainRegistrantChangeArgsDict']]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            timeouts: Optional[pulumi.Input[Union['RegisteredDomainTimeoutsArgs', 'RegisteredDomainTimeoutsArgsDict']]] = None,
            transfer_lock_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            unicode_name: Optional[pulumi.Input[_builtins.str]] = None,
            whois_privacy_enabled: Optional[pulumi.Input[_builtins.bool]] = None) -> 'RegisteredDomain':
        """
        Get an existing RegisteredDomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] auto_renew_enabled: Whether the domain should be set to auto-renew (default: `false`).
        :param pulumi.Input[_builtins.int] contact_id: The ID of the contact to be used for the domain registration. The contact ID can be changed after the domain has been registered. The change will result in a new registrant change, which may result in a [60-day lock](https://support.dnsimple.com/articles/icann-60-day-lock-registrant-change/).
        :param pulumi.Input[_builtins.bool] dnssec_enabled: Whether the domain should have DNSSEC enabled (default: `false`).
        :param pulumi.Input[Union['RegisteredDomainDomainRegistrationArgs', 'RegisteredDomainDomainRegistrationArgsDict']] domain_registration: The domain registration details. (see below for nested schema)
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] extended_attributes: A map of extended attributes to be set for the domain registration. To see if there are any required extended attributes for any TLD use our [Lists the TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes). The values provided in the `extended_attributes` will also be sent when a registrant change is initiated as part of changing the `contact_id`.
        :param pulumi.Input[_builtins.str] name: The domain name to be registered.
        :param pulumi.Input[_builtins.str] premium_price: The premium price for the domain registration. This is only required if the domain is a premium domain. You can use our [Check domain API](https://developer.dnsimple.com/v2/registrar/#checkDomain) to check if a domain is premium and [Retrieve domain prices API](https://developer.dnsimple.com/v2/registrar/#getDomainPrices) to retrieve the premium price for a domain.
        :param pulumi.Input[Union['RegisteredDomainRegistrantChangeArgs', 'RegisteredDomainRegistrantChangeArgsDict']] registrant_change: The registrant change details.
        :param pulumi.Input[_builtins.str] state: (String) - The state of the domain registration.
        :param pulumi.Input[Union['RegisteredDomainTimeoutsArgs', 'RegisteredDomainTimeoutsArgsDict']] timeouts: (see below for nested schema).
        :param pulumi.Input[_builtins.bool] transfer_lock_enabled: Whether the domain transfer lock protection is enabled (default: `true`).
        :param pulumi.Input[_builtins.str] unicode_name: The domain name in Unicode format.
        :param pulumi.Input[_builtins.bool] whois_privacy_enabled: Whether the domain should have WHOIS privacy enabled (default: `false`).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RegisteredDomainState.__new__(_RegisteredDomainState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["auto_renew_enabled"] = auto_renew_enabled
        __props__.__dict__["contact_id"] = contact_id
        __props__.__dict__["dnssec_enabled"] = dnssec_enabled
        __props__.__dict__["domain_registration"] = domain_registration
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["extended_attributes"] = extended_attributes
        __props__.__dict__["name"] = name
        __props__.__dict__["premium_price"] = premium_price
        __props__.__dict__["registrant_change"] = registrant_change
        __props__.__dict__["state"] = state
        __props__.__dict__["timeouts"] = timeouts
        __props__.__dict__["transfer_lock_enabled"] = transfer_lock_enabled
        __props__.__dict__["unicode_name"] = unicode_name
        __props__.__dict__["whois_privacy_enabled"] = whois_privacy_enabled
        return RegisteredDomain(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.int]:
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="autoRenewEnabled")
    def auto_renew_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the domain should be set to auto-renew (default: `false`).
        """
        return pulumi.get(self, "auto_renew_enabled")

    @_builtins.property
    @pulumi.getter(name="contactId")
    def contact_id(self) -> pulumi.Output[_builtins.int]:
        """
        The ID of the contact to be used for the domain registration. The contact ID can be changed after the domain has been registered. The change will result in a new registrant change, which may result in a [60-day lock](https://support.dnsimple.com/articles/icann-60-day-lock-registrant-change/).
        """
        return pulumi.get(self, "contact_id")

    @_builtins.property
    @pulumi.getter(name="dnssecEnabled")
    def dnssec_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the domain should have DNSSEC enabled (default: `false`).
        """
        return pulumi.get(self, "dnssec_enabled")

    @_builtins.property
    @pulumi.getter(name="domainRegistration")
    def domain_registration(self) -> pulumi.Output['outputs.RegisteredDomainDomainRegistration']:
        """
        The domain registration details. (see below for nested schema)
        """
        return pulumi.get(self, "domain_registration")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter(name="extendedAttributes")
    def extended_attributes(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A map of extended attributes to be set for the domain registration. To see if there are any required extended attributes for any TLD use our [Lists the TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes). The values provided in the `extended_attributes` will also be sent when a registrant change is initiated as part of changing the `contact_id`.
        """
        return pulumi.get(self, "extended_attributes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The domain name to be registered.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="premiumPrice")
    def premium_price(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The premium price for the domain registration. This is only required if the domain is a premium domain. You can use our [Check domain API](https://developer.dnsimple.com/v2/registrar/#checkDomain) to check if a domain is premium and [Retrieve domain prices API](https://developer.dnsimple.com/v2/registrar/#getDomainPrices) to retrieve the premium price for a domain.
        """
        return pulumi.get(self, "premium_price")

    @_builtins.property
    @pulumi.getter(name="registrantChange")
    def registrant_change(self) -> pulumi.Output['outputs.RegisteredDomainRegistrantChange']:
        """
        The registrant change details.
        """
        return pulumi.get(self, "registrant_change")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        (String) - The state of the domain registration.
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> pulumi.Output[Optional['outputs.RegisteredDomainTimeouts']]:
        """
        (see below for nested schema).
        """
        return pulumi.get(self, "timeouts")

    @_builtins.property
    @pulumi.getter(name="transferLockEnabled")
    def transfer_lock_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the domain transfer lock protection is enabled (default: `true`).
        """
        return pulumi.get(self, "transfer_lock_enabled")

    @_builtins.property
    @pulumi.getter(name="unicodeName")
    def unicode_name(self) -> pulumi.Output[_builtins.str]:
        """
        The domain name in Unicode format.
        """
        return pulumi.get(self, "unicode_name")

    @_builtins.property
    @pulumi.getter(name="whoisPrivacyEnabled")
    def whois_privacy_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the domain should have WHOIS privacy enabled (default: `false`).
        """
        return pulumi.get(self, "whois_privacy_enabled")

